==> qt-creator-opensource-src-3.1.2.zip: qt-creator-opensource-src-3.1.2/src/plugins/qnx/blackberryruntimeconfiguration.h <==
/**************************************************************************
**
** Copyright (C) 2014 BlackBerry Limited. All rights reserved.
**
** Contact: BlackBerry (qt@blackberry.com)
** Contact: KDAB (info@kdab.com)
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef BLACKBERRYRUNTIMECONFIGURATION_H
#define BLACKBERRYRUNTIMECONFIGURATION_H

#include "blackberryversionnumber.h"

#include <QVariantMap>

namespace Qnx {
namespace Internal {
class BlackBerryRuntimeConfiguration
{
public:
    BlackBerryRuntimeConfiguration(const QString &path,
                                   const BlackBerryVersionNumber &version = BlackBerryVersionNumber());
    BlackBerryRuntimeConfiguration(const QVariantMap &data);

    QString path() const;
    QString displayName() const;
    BlackBerryVersionNumber version() const;
    QVariantMap toMap() const;

private:
    QString m_path;
    QString m_displayName;
    BlackBerryVersionNumber m_version;
};

}
}

#endif // BLACKBERRYRUNTIMECONFIGURATION_H

==> qt-creator-opensource-src-3.2.0.zip: qt-creator-opensource-src-3.2.0/src/plugins/qnx/blackberryruntimeconfiguration.h <==
/**************************************************************************
**
** Copyright (C) 2014 BlackBerry Limited. All rights reserved.
**
** Contact: BlackBerry (qt@blackberry.com)
** Contact: KDAB (info@kdab.com)
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef BLACKBERRYRUNTIMECONFIGURATION_H
#define BLACKBERRYRUNTIMECONFIGURATION_H

#include "qnxversionnumber.h"

#include <QVariantMap>

namespace Qnx {
namespace Internal {
class BlackBerryRuntimeConfiguration
{
public:
    BlackBerryRuntimeConfiguration(const QString &path,
                                   const QnxVersionNumber &version = QnxVersionNumber());
    BlackBerryRuntimeConfiguration(const QVariantMap &data);

    QString path() const;
    QString displayName() const;
    QnxVersionNumber version() const;
    QVariantMap toMap() const;

private:
    QString m_path;
    QString m_displayName;
    QnxVersionNumber m_version;
};

}
}

#endif // BLACKBERRYRUNTIMECONFIGURATION_H
